@@ -1,7 +1,7 @@
 package Perinci::CmdLine;
 
 our $DATE = '2014-10-14'; # DATE
-our $VERSION = '1.33'; # VERSION
+our $VERSION = '1.34'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -845,7 +845,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.33 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2014-10-14.
+This document describes version 1.34 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2014-10-14.
 
 =head1 SYNOPSIS
 
@@ -867,6 +867,12 @@ Screenshots:
 
 <p><img src="http://blogs.perl.org/users/perlancar/progany-tpc.jpg" /><br />Progress bar
 
+<p><img src="http://blogs.perl.org/users/perlancar/screenshot-pericmd-completion.jpg" /><br />Tab completion
+
+<p><img src="http://blogs.perl.org/users/perlancar/screenshot-pericmd-format.jpg" /><br />Some output formats
+
+<p><img src="http://blogs.perl.org/users/perlancar/screenshot-trashu.jpg" /><br />Undo/redo
+
 =end HTML
 
 =head1 REQUEST KEYS
